<?php
/**
 * Photo Fusion Pro customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */


if ( ! function_exists( 'photo_fusion_pro_is_slider_active' ) ) :
	/**
	 * Check if slider is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_slider_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[slider_enable]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_slider_content_type_active' ) ) :
	/**
	 * Check if slider any content type except demo is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_slider_content_type_active( $control ) {
		if ( photo_fusion_pro_is_slider_active( $control ) && 'demo' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_slider_page_content_active' ) ) :
	/**
	 * Check if slider content type page is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_slider_page_content_active( $control ) {
		if ( photo_fusion_pro_is_slider_active( $control ) && 'page' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_slider_post_content_active' ) ) :
	/**
	 * Check if slider content type post is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_slider_post_content_active( $control ) {
		if ( photo_fusion_pro_is_slider_active( $control ) && 'post' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_content_category_active' ) ) :
	/**
	 * Check if slider content type category is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_content_category_active( $control ) {
		if ( photo_fusion_pro_is_slider_active( $control ) && 'category' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_about_active' ) ) :
	/**
	 * Check if about is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_about_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[about_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_is_portfolio_active' ) ) :
	/**
	 * Check if portfolio is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_portfolio_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[portfolio_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_is_blog_section_active' ) ) :
	/**
	 * Check if blog is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_blog_section_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[blog_enable]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_blog_content_demo_inactive' ) ) :
	/**
	 * Check if demo is inactive.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_blog_content_demo_inactive( $control ) {
		if ( photo_fusion_pro_is_blog_section_active( $control ) && 'demo' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[blog_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_blog_content_cat_active' ) ) :
	/**
	 * Check if blog content type category is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_blog_content_cat_active( $control ) {
		if ( photo_fusion_pro_is_blog_section_active( $control ) && 'category' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[blog_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_blog_content_post_active' ) ) :
	/**
	 * Check if blog content type post is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_blog_content_post_active( $control ) {
		if ( photo_fusion_pro_is_blog_section_active( $control ) && 'post' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[blog_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_counter_active' ) ) :
	/**
	 * Check if counter is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_counter_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[counter_enable]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_counter_content_demo_inactive' ) ) :
	/**
	 * Check if counter demo is inactive.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_counter_content_demo_inactive( $control ) {
		if ( photo_fusion_pro_is_counter_active( $control ) && 'demo' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[counter_content_type]' )->value() )
			return true;
		
		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'photo_fusion_pro_theme_options[enable_pagination]' )->value();
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'photo_fusion_pro_theme_options[loader_enable]' )->value();
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_loader_type_image' ) ) :
	/**
	 * Check if loader type image is enabled.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_loader_type_image( $control ) {
		if ( photo_fusion_pro_is_loader_enable( $control ) && 'image-gif' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[loader_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_loader_type_icon' ) ) :
	/**
	 * Check if loader type image is enabled.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_loader_type_icon( $control ) {
		if ( photo_fusion_pro_is_loader_enable( $control ) && 'icon' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[loader_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_photo_gallery_active' ) ) :
	/**
	 * Check if gallery is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_photo_gallery_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_photo_gallery_source_active' ) ) :
	/**
	 * Check if gallery is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_photo_gallery_source_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_photo_gallery_source_category' ) ) :
	/**
	 * Check if gallery content type is category.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_photo_gallery_source_category( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_enable]' )->value() && 'category' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_source]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_photo_gallery_source_category_list' ) ) :
	/**
	 * Check if gallery content type is category list.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_photo_gallery_source_category_list( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_enable]' )->value() && 'category-list' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_source]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_photo_gallery_source_not_demo' ) ) :
	/**
	 * Check if gallery content type is not demo.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_photo_gallery_source_not_demo( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_enable]' )->value() && 'demo' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_source]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_photo_gallery_layout' ) ) :
	/**
	 * Check if gallery is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_photo_gallery_layout( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_enable]' )->value() && 'grid' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_image_layout]' )->value() && 'demo' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[photo_gallery_source]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_portfolio_source_active' ) ) :
	/**
	 * Check if portfolio category active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_portfolio_source_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[portfolio_enable]' )->value() && 'category' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[portfolio_source]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_is_about_active' ) ) :
	/**
	 * Check if about is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_about_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[about_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_is_contact_address_active' ) ) :
	/**
	 * Check if contact address is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_contact_address_active( $control ) {
		return $control->manager->get_setting( 'photo_fusion_pro_theme_options[enable_address_block]' )->value();
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_contact_form_active' ) ) :
	/**
	 * Check if contact form is active.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_is_contact_form_active( $control ) {
		return $control->manager->get_setting( 'photo_fusion_pro_theme_options[enable_contact_form]' )->value();
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_contact_map_shortcode' ) ) :
	/**
	 * Check contact map type
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_contact_map_shortcode( $control ) {
		if ( true == $control->manager->get_setting( 'photo_fusion_pro_theme_options[enable_contact_form]' )->value() && 'shortcode' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[map_type_option]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_contact_map_embed' ) ) :
	/**
	 * Check contact map type
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_contact_map_embed( $control ) {
		if ( true == $control->manager->get_setting( 'photo_fusion_pro_theme_options[enable_contact_form]' )->value() && 'embed' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[map_type_option]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'photo_fusion_pro_about_section_soruce' ) ) :
	/**
	 * Check if about section is page.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_about_section_soruce( $control ) {
		if ( 'demo' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[about_type]' )->value() && 'disabled' != $control->manager->get_setting( 'photo_fusion_pro_theme_options[about_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_color_theme_type_theme' ) ) :
	/**
	 * Check if color theme type is color theme.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_color_theme_type_theme( $control ) {
		if ( 'color-theme' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[color_theme_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'photo_fusion_pro_color_theme_type_picker' ) ) :
	/**
	 * Check if color theme type is color picker.
	 *
	 * @since Photo Fusion Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function photo_fusion_pro_color_theme_type_picker( $control ) {
		if ( 'color-picker' == $control->manager->get_setting( 'photo_fusion_pro_theme_options[color_theme_type]' )->value() )
			return true;

		return false;
	}
endif;