<?php
/**
 * Photo Fusion Pro customizer default options
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */


/**
 * Returns the default options for photo-fusion-pro.
 *
 * @since Photo Fusion Pro 1.0
 * @return array An array of default values
 */
function photo_fusion_pro_get_default_theme_options() {
	$theme_data  = wp_get_theme(); // get theme data
	$photo_fusion_pro_default_options = array(

		//Menu options
		'primary_menu_sticky_enable' 	=> true,

		//Default color layout
		'color_layout_options'		  	=> 'default',

		//Typoography
		'theme_typography' 				=> 'open-sans',

		// animation
		'site_animation_layout'			=> true,

		//Slider options

		'slider_enable'         		=> 'static-frontpage',
		'slider_content_type'   		=> 'demo',
		'slider_content_effect' 		=> 'fadeout',
		'slider_content_speed'  		=> 500,
		'slider_content_page_count'  	=> 2,
		'enable_slider_captions'     	=> true,
		'enable_arrow_controls'      	=> true,
		'enable_slider_pager'        	=> true,
		'enable_slider_control_at_bottom' => false,
		'slider_excerpt_length' 		=> 25,
		'enable_slider_excerpt' 		=> true,
		'slider_button_text' 			=> esc_html__( 'View Details', 'photo-fusion-pro' ),

		//About options
		'about_enable'             		=> 'static-frontpage',
		'about_type'             		=> 'demo',
		'about_content_type'            => 0,

		//Photo Gallery options
		'photo_gallery_enable'          => 'static-frontpage',
		'photo_gallery_image_layout'    => 'grid',
		'photo_gallery_source'    		=> 'demo',
		'photo_gallery_no_of_img'    	=> 10,

		//Portfolio options
		'portfolio_title'          		=> esc_html__( 'My Latest Work', 'photo-fusion-pro' ),
		'portfolio_description'         => esc_html__( 'Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.', 'photo-fusion-pro' ),
		'portfolio_enable'         		=> 'static-frontpage',
		'portfolio_source'    			=> 'demo',
		'portfolio_no_of_img'    		=> 8,
		'portfolio_image_layout'    	=> 'grid',

		//gallery page options
		'gallery_content_type'    		=> 0,
		'gallery_image_layout'    		=> 'grid',


		//Service options
		'service_enable'       			=> 'static-frontpage',
		'service_section_title'			=> esc_html__( 'our services', 'photo-fusion-pro' ),
		'service_content_type'			=> 'demo',
		'service_content_count'			=> 3,

		//blog options
		'blog_enable'              		=> 'static-frontpage',
		'blog_title'               		=> esc_html__( 'Blog Posts', 'photo-fusion-pro' ),
		'blog_description'				=> esc_html__( 'Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit.', 'photo-fusion-pro' ),
		'blog_count'					=> 3,
		'blog_content_type'				=> 'demo',

		//Features options

		'counter_enable'          		=> 'static-frontpage',
		'counter_count'					=> 4,
		'counter_content_type'			=> 'demo',
		'counter_bg_image'				=> esc_url( get_template_directory_uri(). '/assets/uploads/background-01.jpg' ),

		//Contact options
		'contact_enable'           		=> 'static-frontpage',
		'contact_section_title'    		=> esc_html__( 'Get in touch <span class="color-green">with us</span>', 'photo-fusion-pro' ),

		/**
		* Theme Options
		*/
		'excerpt_length'           		=> 15,
		'footer_logo'              		=> '',
		'copyright_text'           		=> sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'photo-fusion-pro' ), '[the-year]', '[site-link]' ) . ' &#124; ' . $theme_data->get( 'Name') . '&nbsp;' . esc_html__( 'by', 'photo-fusion-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. $theme_data->get( 'Author' ) .'</a>',
		'enable_pagination'        		=> true,
		'pagination_type'          		=> 'numeric',
		'sidebar_position'         		=> 'right-sidebar',
		'site_layout'         			=> 'wide',
		'loader_enable'         		=> true,
		'loader_type'         			=> 'icon',
		'loader_gif'         			=> get_template_directory_uri() . '/assets/images/loading.gif',
		'loader_icon'         			=> 'fa-refresh',
		'gallery_with_gap'				=> 'gallery-no-gap',
		'color_theme_type'				=> 'color-theme',
		'theme_color'					=> '#f23f30',
		'theme_button_hover_color'		=> '#9e0c05',
		'theme_post_meta_color'			=> '#ffe930',

		'reset_options'      			=> false,
		'enable_frontpage_content' 		=> true,

		//Contact template
		'enable_address_block'			=> true,
		'map_type_option'				=> 'embed',
		'contact_address_icon'			=> 'fa-circle-o-notch',
		'contact_address_title'			=> esc_html__( 'Our Address', 'photo-fusion-pro' ),
		'contact_address_description'	=> esc_html__( '28 Jackson Blvd Ste 1020 Chicago IL ', 'photo-fusion-pro' ),

		'contact_phone_icon'			=> 'fa-envelope',
		'contact_phone_title'			=> esc_html__( 'Phone / Fax:', 'photo-fusion-pro' ),
		'contact_phone_number'			=> '+7 (800) 123 45 69',

		'contact_email_icon'			=> 'fa-envelope',
		'contact_email_title'			=> esc_html__( 'Say hello!', 'photo-fusion-pro' ),
		'contact_email_id'				=> esc_html__( 'info@photography.com', 'photo-fusion-pro' ),

		'social_menu_icon'				=> 'fa-circle-o-notch',
		'social_icon_title'				=> esc_html__( 'Follow us on:', 'photo-fusion-pro' ),
		'no_of_social_icon'				=> 5,
		'social_link_1'					=> esc_url( 'facebook.com' ),
		'social_link_2'					=> esc_url( 'twitter.com' ),
		'social_link_3'					=> esc_url( 'linkedin.com' ),
		'social_link_4'					=> esc_url( 'plus.google.com' ),
		'social_link_5'					=> esc_url( 'instagram.com' ),

		'enable_contact_form'			=> true,

	);

	$output = apply_filters( 'photo_fusion_pro_default_theme_options', $photo_fusion_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}