<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */


if ( ! function_exists( 'photo_fusion_pro_add_counter_section' ) ) :
    /**
     * Add counter section
     *
     * @since Photo Fusion Pro 1.0
     */
    function photo_fusion_pro_add_counter_section() {
      // Check if counter is enabled on frontpage
      $counter_enable = apply_filters( 'photo_fusion_pro_section_status', true, 'counter_enable' );
      if ( true !== $counter_enable ) {
          return false;
      }

      // Get counter section details
      $section_details = array();
      $section_details = apply_filters( 'photo_fusion_pro_filter_counter_section_details', $section_details );

      if ( empty( $section_details ) ) {
          return;
      }

      // Render counter section now.
      photo_fusion_pro_render_counter_section( $section_details );
    }
endif;
add_action( 'photo_fusion_pro_primary_content_end', 'photo_fusion_pro_add_counter_section', 80 );

if ( ! function_exists( 'photo_fusion_pro_get_counter_section_details' ) ) :
    /**
     * counter section details.
     *
     * @since Photo Fusion Pro 1.0
     *
     * @param array $input counter section details.
     */
    function photo_fusion_pro_get_counter_section_details( $input ) {
      $options = photo_fusion_pro_get_theme_options();
      // Slider type
      $counter_content_type  = $options['counter_content_type'];

      $content = array();

      switch ( $counter_content_type ) {
        case 'demo':
          for ( $i=0; $i<4; $i++ ) {
            $icons = array( 'fa-cloud-upload', 'fa-file-photo-o', 'fa-instagram', 'fa-user' );
            $counter_name = array( esc_html__( 'IMAGES UPLOADED','photo-fusion-pro' ), esc_html__( 'PHOTO GALLERIES','photo-fusion-pro' ), esc_html__( 'PHOTO SHOOTS','photo-fusion-pro' ), esc_html__( 'CLIENTS SERVED','photo-fusion-pro' ) );

            $content[ $i ]['counter_icon'] = $icons[ $i ];
            $content[ $i ]['counter_name'] = $counter_name[ $i ];
            $content[ $i ]['counter_count'] = 999;
          }
        break;

        case 'custom':
          for ( $i = 1; $i <= $options['counter_count']; $i++ ) {
            if ( isset( $options[ 'counter_icon_'.$i ] ) ) {
              $content[ $i ]['counter_icon'] = $options[ 'counter_icon_'.$i ];
            } else{
              $content[ $i ]['counter_icon'] = '';
            }
            if ( isset( $options[ 'counter_name_'.$i ] ) ) {
              $content[ $i ]['counter_name'] = $options[ 'counter_name_'.$i ];
            } else{
              $content[ $i ]['counter_name'] = '';
            }
            if ( isset( $options[ 'counter_count_'.$i ] ) ) {
              $content[ $i ]['counter_count'] = $options[ 'counter_count_'.$i ];
            } else{
              $content[ $i ]['counter_count'] = '';
            }
          }
        break;
      }

      if ( ! empty( $content ) ) {
          $input = $content;
      }

      return $input;
    }
endif;
// counter section content details.
add_filter( 'photo_fusion_pro_filter_counter_section_details', 'photo_fusion_pro_get_counter_section_details' );

if ( ! function_exists( 'photo_fusion_pro_render_counter_section' ) ) :
    /**
     * Start section id .pie-chart
     *
     * @return string pie-chart content
     * @since Photo Fusion Pro 1.0
     *
     */
    function photo_fusion_pro_render_counter_section( $content_details = array() ) {
        $options = photo_fusion_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="counter">
          <!-- <div class="black-overlay"></div> --><!-- end .black-overlay -->
          <div class="container page-section">
            <div class="entry-content">
              <div class="statscounts">

              <?php foreach ( $content_details as $content ) :
                if ( ! empty( $content['counter_icon'] ) ||  ! empty( $content['counter_name'] ) ||  ! empty( $content['counter_count'] ) ) { ?>
                <div class="statwrap os-animation" data-os-animation="fadeInUp" data-os-animation-delay="0.1s" data-os-animation-duration="1s">
                <?php if( !empty( $content['counter_icon'] ) ){ ?>
                  <i class="fa <?php echo esc_html( $content['counter_icon'] ); ?>"></i>
                <?php } ?>

                <?php if( !empty( $content['counter_count'] ) ){ ?>
                    <span class="stat-count"><?php echo absint( $content['counter_count'] ); ?></span>
                <?php } ?>

                <?php if( !empty( $content['counter_name'] ) ){ ?>
                    <small><?php echo esc_html( $content['counter_name'] ); ?></small>
                <?php } ?>
                </div><!-- end .statwrap -->
              <?php }
               endforeach; ?>

              <div class="clear"></div><!-- end .clear -->
            </div><!-- end .entry-content -->
          </div><!-- end .container -->
        </section><!-- end #counter -->
<?php
    }
endif;